@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # Copyright 2013 - Noorul Islam K M
 #
@@ -16,7 +15,7 @@
 
 import json
 
-from tempest_lib import exceptions as tempest_exceptions
+from tempest.lib import exceptions as tempest_exceptions
 
 from functionaltests.api import base
 
