@@ -46,7 +46,11 @@ class App(api_types.Base):
     ports = api_types.MultiType(api_types.PortType,
                                 [api_types.PortType],
                                 {wtypes.text: api_types.PortType})
-    source = {wtypes.text: wtypes.text}
+    source = wtypes.DictType(wtypes.text, api_types.MultiType(
+        wtypes.text,
+        six.integer_types,
+        bool,
+        float))
     workflow_config = {wtypes.text: wtypes.text}
     trigger_uuid = wtypes.text
     trigger_actions = [wtypes.text]
@@ -57,7 +61,9 @@ class App(api_types.Base):
     status = wtypes.text
     repo_token = wtypes.text
     created_at = datetime.datetime
+    updated_at = datetime.datetime
     raw_content = wtypes.text
+    repo_token = wtypes.text
     scale_config = wtypes.DictType(
         wtypes.text,
         wtypes.DictType(wtypes.text, wtypes.text))
@@ -105,7 +111,8 @@ class App(api_types.Base):
             'trigger_actions',
             'workflow_config',
             'stack_id',
-            'raw_content'
+            'raw_content',
+            'repo_token'
             ]
         base = super(App, self).as_dict(db_model)
 
