@@ -17,6 +17,7 @@
 import eventlet
 from oslo_config import cfg
 import oslo_messaging as messaging
+from oslo_messaging.rpc import dispatcher
 from oslo_serialization import jsonutils
 
 import solum.common.context
@@ -64,11 +65,13 @@ class Service(object):
 
     def __init__(self, topic, server, handlers):
         serializer = RequestContextSerializer(JsonPayloadSerializer())
-        transport = messaging.get_transport(cfg.CONF)
+        transport = messaging.get_notification_transport(cfg.CONF)
         # TODO(asalkeld) add support for version='x.y'
         target = messaging.Target(topic=topic, server=server)
+        access_policy = dispatcher.DefaultRPCAccessPolicy
         self._server = messaging.get_rpc_server(transport, target, handlers,
-                                                serializer=serializer)
+                                                serializer=serializer,
+                                                access_policy=access_policy)
 
     def serve(self):
         objects.load()
@@ -80,7 +83,7 @@ class API(object):
     def __init__(self, transport=None, context=None, topic=None):
         serializer = RequestContextSerializer(JsonPayloadSerializer())
         if transport is None:
-            transport = messaging.get_transport(cfg.CONF)
+            transport = messaging.get_notification_transport(cfg.CONF)
         self._context = context
         if topic is None:
             topic = ''
